==> react-native-media-queries-0.0.2.tgz: package/index.js <==

/*
Copyright (c) 2016, Marco Sampellegrini <babbonatale@alpacaaa.net>

Permission to use, copy, modify, and/or distribute this software for any purpose with or without fee
is hereby granted, provided that the above copyright notice and this permission notice appear in all copies.
THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE
INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE
FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/


const Dimensions = require('react-native').Dimensions;


export const createStyles = (base, ...extra) => {
  return extra.reduce((acc, fn) => {
    const properties = fn(Dimensions.get('window'));
    const merged = Object.keys(properties).reduce((s_acc, key) =>
      ({
        ...s_acc,
        [key]: {...base[key], ...properties[key]}
      }), {});

    return {
      ...acc,
      ...merged
    }

  }, base);
};


const createQueryFn = (test) => (target, styles) => (dimensions) => {
  if (!test(target, dimensions)) return {};

  return typeof styles == 'function' ? styles(dimensions) : styles;
};

export const maxHeight = createQueryFn((target, { height }) => target >= height);
export const minHeight = createQueryFn((target, { height }) => target <= height);

export const maxWidth = createQueryFn((target, { width }) => target >= width);
export const minWidth = createQueryFn((target, { width }) => target <= width);

==> react-native-media-queries-0.0.5.tgz: package/index.js <==

/*
Copyright (c) 2016, Marco Sampellegrini <babbonatale@alpacaaa.net>

Permission to use, copy, modify, and/or distribute this software for any purpose with or without fee
is hereby granted, provided that the above copyright notice and this permission notice appear in all copies.
THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE
INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE
FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/


const Dimensions = require('react-native').Dimensions;


export const createStyles = (base, ...extra) => {
  const dimensions = Dimensions.get('window');

  return extra.reduce((acc, fn) => {
    const properties = fn(dimensions);
    const merged = Object.keys(properties).reduce((s_acc, key) =>
      ({
        ...s_acc,
        [key]: {...base[key], ...properties[key]}
      }), {});

    return {
      ...acc,
      ...merged
    };

  }, base);
};


const createQueryFn = (test) => (target, styles) => (dimensions) => {
  if (!test(target, dimensions)) return {};

  return typeof styles == 'function' ? styles(dimensions) : styles;
};

export const maxHeight = createQueryFn((target, { height }) => target >= height);
export const minHeight = createQueryFn((target, { height }) => target <= height);

export const maxWidth = createQueryFn((target, { width }) => target >= width);
export const minWidth = createQueryFn((target, { width }) => target <= width);
